@@ -163,7 +163,7 @@ def from_response(response, body):
         message = "n/a"
         details = "n/a"
         if hasattr(body, 'keys'):
-            error = body[body.keys()[0]]
+            error = body[list(body.keys())[0]]
             message = error.get('message', None)
             details = error.get('details', None)
         return cls(code=response.status, message=message, details=details)
