@@ -21,7 +21,7 @@ Command-line interface to the OpenStack Trove API.
 import argparse
 import getpass
 import glob
-import imp
+import importlib
 import itertools
 import logging
 import os
@@ -34,7 +34,6 @@ from keystoneauth1 import loading
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 import pkg_resources
-import six
 
 from troveclient.apiclient import exceptions as exc
 import troveclient.auth_plugin
@@ -299,6 +298,14 @@ class OpenStackTroveShell(object):
 
                 yield name, module
 
+    def _load_module(self, name, path):
+        module_spec = importlib.spec_from_file_location(
+            name, path
+        )
+        module = importlib.module_from_spec(module_spec)
+        module_spec.loader.exec_module(module)
+        return module
+
     def _discover_via_contrib_path(self, version):
         module_path = os.path.dirname(os.path.abspath(__file__))
         version_str = "v%s" % version.replace('.', '_')
@@ -312,7 +319,7 @@ class OpenStackTroveShell(object):
             if name == "__init__":
                 continue
 
-            module = imp.load_source(name, ext_path)
+            module = self._load_module(name, ext_path)
             yield name, module
 
     def _discover_via_entry_points(self):
@@ -750,8 +757,8 @@ def main():
         sys.exit(130)
     except Exception as e:
         LOG.debug(e, exc_info=1)
-        message = six.text_type(e)
-        if not isinstance(message, six.string_types):
+        message = str(e)
+        if not isinstance(message, str):
             message = str(message)
         print(_("ERROR: %s") % encodeutils.safe_encode(message),
               file=sys.stderr)
