@@ -14,9 +14,9 @@
 #    under the License.
 #
 
-import Crypto.Random
-import mock
+import os
 import testtools
+from unittest import mock
 
 from troveclient.v1 import modules
 
@@ -55,7 +55,7 @@ class TestModules(testtools.TestCase):
             return path, body, mod
 
         text_contents = "my_contents"
-        binary_contents = Crypto.Random.new().read(20)
+        binary_contents = os.urandom(20)
         for contents in [text_contents, binary_contents]:
             self.modules._create = mock.Mock(side_effect=side_effect_func)
             path, body, mod = self.modules.create(
@@ -123,3 +123,35 @@ class TestModules(testtools.TestCase):
         self.modules.delete(self.module)
         resp.status_code = 500
         self.assertRaises(Exception, self.modules.delete, self.module_name)
+
+    def _test_instances(self, expected_query=None):
+        page_mock = mock.Mock()
+        self.modules._paginated = page_mock
+        limit = "test-limit"
+        marker = "test-marker"
+        if not expected_query:
+            expected_query = {}
+        self.modules.instances(self.module_name, limit, marker,
+                               **expected_query)
+        page_mock.assert_called_with("/modules/mod_1/instances",
+                                     "instances", limit, marker,
+                                     query_strings=expected_query)
+
+    def test_instance_count(self):
+        expected_query = {'include_clustered': True,
+                          'count_only': True}
+        self._test_instances(expected_query)
+
+    def test_instances(self):
+        expected_query = {'include_clustered': True}
+        self._test_instances(expected_query)
+
+    def test_reapply(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = None
+        self.modules.api.client.put = mock.Mock(return_value=(resp, body))
+        self.modules.reapply(self.module_name)
+        self.modules.reapply(self.module)
+        resp.status_code = 500
+        self.assertRaises(Exception, self.modules.reapply, self.module_name)
